@@ -109,7 +109,6 @@ OC.L10N.register(
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Items in the trash bin are deleted after {numDays} day","Items in the trash bin are deleted after {numDays} days"],
     "Could not update calendar order." : "Could not update calendar order.",
     "Deck" : "برگه‌دان",
-    "Hidden" : "مخفی",
     "Internal link" : "پیوند داخلی",
     "A private link that can be used with external clients" : "A private link that can be used with external clients",
     "Copy internal link" : "کپی کردن پیوند داخلی",
@@ -131,12 +130,10 @@ OC.L10N.register(
     "Deleting share link …" : "در حال حذف پیوند اشتراک ...",
     "An error occurred while unsharing the calendar." : "An error occurred while unsharing the calendar.",
     "An error occurred, unable to change the permission of the share." : "خطایی روی داد ، قادر به تغییر مجوز اشتراک نیست.",
-    "can edit" : "می توان ویرایش کرد",
     "Unshare with {displayName}" : "عدم اشتراک گذاری با {displayName}",
     "Share with users or groups" : "اشتراک گذاری با کاربران یا گروه ها ...",
     "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
     "Failed to save calendar name and color" : "Failed to save calendar name and color",
-    "Calendar name …" : "نام تقویم …",
     "Share calendar" : "Share calendar",
     "Unshare from me" : "بی خبر از من",
     "Save" : "ذخیره",
@@ -152,13 +149,13 @@ OC.L10N.register(
     "Invalid location selected" : "مکان نامعتبر انتخاب شده است",
     "Attachments folder successfully saved." : "Attachments folder successfully saved.",
     "Error on saving attachments folder." : "Error on saving attachments folder.",
-    "Default attachments location" : "Default attachments location",
+    "Attachments folder" : "Attachments folder",
     "{filename} could not be parsed" : "{filename} could not be parsed",
     "No valid files found, aborting import" : "No valid files found, aborting import",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Successfully imported %n event","Successfully imported %n events"],
     "Import partially failed. Imported {accepted} out of {total}." : "وارد کردن تا حدودی انجام نشد. وارد شده {accepted} بیرون از {total}.",
     "Automatic" : "خودکار",
-    "Automatic ({detected})" : "خودکار ({شناسایی})",
+    "Automatic ({timezone})" : "خودکار ({شناسایی})",
     "New setting was not saved successfully." : "تنظیم جدید با موفقیت ذخیره نشد.",
     "Navigation" : "جهت یابی",
     "Previous period" : "دوره قبلی",
@@ -183,13 +180,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "پیوند CalDAV در کلیپ بورد کپی شد.",
     "CalDAV link could not be copied to clipboard." : "پیوند CalDAV در کلیپ بورد قابل کپی نیست.",
     "General" : "عمومی",
-    "Personal availability settings" : "Personal availability settings",
-    "Copy primary CalDAV address" : "آدرس اصلی CalDAV را کپی کنید",
     "Copy iOS/macOS CalDAV address" : "آدرس CalDAV iOS / macOS را کپی کنید",
-    "Enable birthday calendar" : "تقویم تولد را فعال کنید",
-    "Show tasks in calendar" : "نمایش وظایف در تقویم",
-    "Show weekends" : "آخر هفته ها را نشان دهید",
-    "Show week numbers" : "نمایش شماره های هفته",
+    "Appearance" : "ظاهر",
     "Editing" : "ویرایش کردن",
     "Default reminder" : "Default reminder",
     "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید",
@@ -362,6 +354,7 @@ OC.L10N.register(
     "Yes" : "بله",
     "No" : "خیر",
     "Maybe" : "Maybe",
+    "None" : "هیچ‌کدام",
     "Create" : "ایجاد",
     "from {formattedDate}" : "از {formattedDate}",
     "to {formattedDate}" : "به {formattedDate}",
@@ -483,7 +476,6 @@ OC.L10N.register(
     "When shared show full event" : "هنگام اشتراک گذاری ، رویداد کامل را نشان می دهد",
     "When shared show only busy" : "وقتی نمایش اشتراکی فقط مشغول است",
     "When shared hide this event" : "هنگام اشتراک گذاری این رویداد را پنهان کنید",
-    "The visibility of this event in shared calendars." : "قابلیت مشاهده این رویداد در تقویمهای مشترک.",
     "Add a location" : "افزودن یک محل",
     "Status" : "وضعیت",
     "Confirmed" : "تایید شده",
@@ -506,10 +498,22 @@ OC.L10N.register(
     "This is an event reminder." : "This is an event reminder.",
     "Appointment not found" : "Appointment not found",
     "User not found" : "کاربر یافت نشد",
+    "Hidden" : "مخفی",
+    "can edit" : "می توان ویرایش کرد",
+    "Calendar name …" : "نام تقویم …",
+    "Default attachments location" : "Default attachments location",
+    "Automatic ({detected})" : "خودکار ({شناسایی})",
     "Shortcut overview" : "Shortcut overview",
+    "Enable birthday calendar" : "تقویم تولد را فعال کنید",
+    "Show tasks in calendar" : "نمایش وظایف در تقویم",
     "Enable simplified editor" : "ویرایشگر ساده شده را فعال کنید",
     "Limit the number of events displayed in the monthly view" : "Limit the number of events displayed in the monthly view",
+    "Show weekends" : "آخر هفته ها را نشان دهید",
+    "Show week numbers" : "نمایش شماره های هفته",
     "Time increments" : "Time increments",
-    "Show keyboard shortcuts" : "Show keyboard shortcuts"
+    "Copy primary CalDAV address" : "آدرس اصلی CalDAV را کپی کنید",
+    "Personal availability settings" : "Personal availability settings",
+    "Show keyboard shortcuts" : "Show keyboard shortcuts",
+    "The visibility of this event in shared calendars." : "قابلیت مشاهده این رویداد در تقویمهای مشترک."
 },
 "nplurals=2; plural=(n > 1);");
