@@ -142,12 +142,10 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (tiimi)",
     "An error occurred while unsharing the calendar." : "Kalenterin jaon poistamisessa tapahtui virhe.",
     "An error occurred, unable to change the permission of the share." : "Tapahtui virhe, jaon käyttöoikeuksia ei pysty muokkaamaan.",
-    "can edit" : "voi muokata",
     "Unshare with {displayName}" : "Poista jako kohteesta {displayName}",
     "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
     "No users or groups" : "Ei käyttäjiä tai ryhmiä",
     "Failed to save calendar name and color" : "Kalenterin nimen ja värin tallentaminen epäonnistui",
-    "Calendar name …" : "Kalenterin nimi…",
     "Share calendar" : "Jaa kalenteri",
     "Unshare from me" : "Lopeta jako minulle",
     "Save" : "Tallenna",
@@ -170,7 +168,8 @@ OC.L10N.register(
     "Pick" : "Valitse",
     "Invalid location selected" : "Virheellinen sijainti valittu",
     "Attachments folder successfully saved." : "Liitteiden kansio tallennettu.",
-    "Default attachments location" : "Liitteiden oletussijainti",
+    "Error on saving attachments folder." : "Virhe liitetiedostokansiota tallennettaessa.",
+    "Attachments folder" : "Liitteiden kansio",
     "{filename} could not be parsed" : "Tiedostoa {filename} ei voitu jäsentää",
     "No valid files found, aborting import" : "Kelvollisia tiedostoja ei löytynyt, lopetetaan tuonti",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Tuotiin onnistuneesti %n tapahtuma","Tuotiin onnistuneesti %n tapahtumaa"],
@@ -204,15 +203,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "CalDAV-linkki kopioitu leikepöydälle.",
     "CalDAV link could not be copied to clipboard." : "CalDAV-linkkiä ei voitu kopioida leikepöydälle.",
     "General" : "Yleiset",
-    "Personal availability settings" : "Henkilökohtaiset saatavuusasetukset",
-    "Copy primary CalDAV address" : "Kopioi ensisijainen CalDAV-osoite",
     "Copy iOS/macOS CalDAV address" : "Kopioi iOS:in/macOS:n CalDAV-osoite",
-    "View options" : "Näkymävalinnat",
-    "Enable birthday calendar" : "Käytä syntymäpäiväkalenteria",
-    "Show tasks in calendar" : "Näytä tehtävät kalenterissa",
-    "Show weekends" : "Näytä viikonloput",
-    "Show week numbers" : "Näytä viikkonumerot",
-    "Limit number of events shown in month view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää",
+    "Appearance" : "Ulkoasu",
     "Default calendar for incoming invitations" : "Oletuskalenteri saapuville kutsuille",
     "Default reminder" : "Oletusmuistutus",
     "Keyboard shortcuts" : "Pikanäppäimet",
@@ -267,6 +259,7 @@ OC.L10N.register(
     "Could not book the appointment. Please try again later or contact the organizer." : "Tapaamista ei voitu kirjata. Ole hyvä ja yritä myöhemmin uudelleen tai ota yhteyttä järjestäjään.",
     "Back" : "Takaisin",
     "Book appointment" : "Varaa tapaaminen",
+    "Error fetching Talk conversations." : "Virhe noudettaessa Talk-keskusteluja.",
     "Conversation does not have a valid URL." : "Keskustelulla ei ole kelvollista URL-osoitetta.",
     "Successfully added Talk conversation link to location." : "Talk-keskustelulinkki lisätty sijaintiin.",
     "Successfully added Talk conversation link to description." : "Talk-keskustelulinkki lisätty kuvaukseen.",
@@ -375,8 +368,8 @@ OC.L10N.register(
     "Remove color" : "Poista väri",
     "Event title" : "Tapahtuman otsikko",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Koko päivän tapahtumia, jotka ovat osa toistuvaa tapahtumaa, ei voida muokata.",
-    "From" : "Lähettäjä",
-    "To" : "Vastaanottaja",
+    "From" : "Alkaen",
+    "To" : "Päättyen",
     "Repeat" : "Toista",
     "_time_::_times_" : ["kerran","kertaa"],
     "never" : "ei koskaan",
@@ -589,7 +582,6 @@ OC.L10N.register(
     "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
     "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
     "When shared hide this event" : "Jaettaessa piilota tämä tapahtuma",
-    "The visibility of this event in shared calendars." : "Tämän tapahtuman näkyvyys jaetuissa kalentereissa.",
     "Add a location" : "Lisää sijainti",
     "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Lisää kuvaus\n\n- Mitä tapaamisessa käsitellään\n- Asialista\n- Mitä hyvänsä mihin osallistujien tulisi valmistautua",
     "Status" : "Tila",
@@ -618,11 +610,23 @@ OC.L10N.register(
     "Appointment not found" : "Tapaamista ei löydy",
     "User not found" : "Käyttäjää ei löydy",
     "Hidden" : "Piilotettu",
+    "can edit" : "voi muokata",
+    "Calendar name …" : "Kalenterin nimi…",
+    "Default attachments location" : "Liitteiden oletussijainti",
     "Automatic ({detected})" : "Automaattinen ({detected})",
     "Shortcut overview" : "Pikakuvakenäkymä",
+    "Enable birthday calendar" : "Käytä syntymäpäiväkalenteria",
+    "Show tasks in calendar" : "Näytä tehtävät kalenterissa",
     "Enable simplified editor" : "Käytä yksinkertaistettua muokkainta",
     "Limit the number of events displayed in the monthly view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää",
+    "Show weekends" : "Näytä viikonloput",
+    "Show week numbers" : "Näytä viikkonumerot",
     "Time increments" : "Aikavälit",
-    "Show keyboard shortcuts" : "Näytä pikanäppäimet"
+    "Copy primary CalDAV address" : "Kopioi ensisijainen CalDAV-osoite",
+    "Personal availability settings" : "Henkilökohtaiset saatavuusasetukset",
+    "Show keyboard shortcuts" : "Näytä pikanäppäimet",
+    "The visibility of this event in shared calendars." : "Tämän tapahtuman näkyvyys jaetuissa kalentereissa.",
+    "View options" : "Näkymävalinnat",
+    "Limit number of events shown in month view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää"
 },
 "nplurals=2; plural=(n != 1);");
