@@ -19,15 +19,15 @@ OC.L10N.register(
     "Deleted" : "Delite",
     "Restore" : "Restaurar",
     "Delete permanently" : "Deler permanentemente",
-    "Hidden" : "Occultate",
     "Share link" : "Compartir ligamine",
-    "can edit" : "pote modificar",
     "Share with users or groups" : "Compartir con usatores o gruppos",
     "Save" : "Salveguardar",
+    "View" : "Vider",
     "Cancel" : "Cancellar",
     "Automatic" : "Automatic",
     "Actions" : "Actiones",
-    "Show week numbers" : "Monstrar le numero del septimanas",
+    "General" : "General",
+    "Keyboard shortcuts" : "Combinationes de claves",
     "Update" : "Actualisar",
     "Location" : "Loco",
     "Description" : "Description",
@@ -48,8 +48,8 @@ OC.L10N.register(
     "days" : "dies",
     "weeks" : "septimanas",
     "Choose a file to add as attachment" : "Selectiona un file pro adder como attachamento",
-    "Unknown" : "Incognite",
     "Done" : "Preste",
+    "Unknown" : "Incognite",
     "Accept" : "Acceptar",
     "Decline" : "Refusar",
     "Tentative" : "Tentative",
@@ -57,10 +57,11 @@ OC.L10N.register(
     "Repeat" : "Repeter",
     "never" : "nunquam",
     "after" : "post",
+    "None" : "Nulle",
     "Global" : "Global",
     "Subscribe" : "Subscribe",
     "Personal" : "Personal",
-    "Details" : "Detalios",
+    "Edit event" : "Modificar evento",
     "Close" : "Clauder",
     "Anniversary" : "Anniversario de evento",
     "Week {number} of {year}" : "Septimana {number} de {year}",
@@ -71,6 +72,9 @@ OC.L10N.register(
     "When shared show full event" : "Quando compartite, monstrar evento integremente",
     "When shared show only busy" : "Quando compartite, monstrar solo si illo es occupate",
     "When shared hide this event" : "Quando compartite, celar iste evento",
-    "Confirmed" : "Confirmate"
+    "Confirmed" : "Confirmate",
+    "Hidden" : "Occultate",
+    "can edit" : "pote modificar",
+    "Show week numbers" : "Monstrar le numero del septimanas"
 },
 "nplurals=2; plural=(n != 1);");
