@@ -115,7 +115,6 @@ OC.L10N.register(
     "Could not update calendar order." : "Gat ekki uppfært röð dagatalanna.",
     "Shared calendars" : "Sameiginleg dagatöl",
     "Deck" : "Deck-spjaldaforrit",
-    "Hidden" : "Falinn",
     "Internal link" : "Innri tengill",
     "A private link that can be used with external clients" : "Einkatengill sem hægt er að nota með öðrum forritum",
     "Copy internal link" : "Afrita innri tengil",
@@ -138,12 +137,10 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Teymi)",
     "An error occurred while unsharing the calendar." : "Villa kom upp við að taka dagatalið úr samnýtingu.",
     "An error occurred, unable to change the permission of the share." : "Villa kom upp, gat ekki breytt heimildum á sameigninni.",
-    "can edit" : "getur breytt",
     "Unshare with {displayName}" : "Hætta deilingu með {displayName}",
     "Share with users or groups" : "Deila með notendum eða hópum",
     "No users or groups" : "Engir notendur eða hópar",
     "Failed to save calendar name and color" : "Mistókst að vista heiti og lit dagatals",
-    "Calendar name …" : "Heiti dagatals …",
     "Never show me as busy (set this calendar to transparent)" : "Aldrei sýna mig sem upptekinn/upptekna (stilla þetta dagatal á að vera gegnsætt)",
     "Share calendar" : "Deila dagatali",
     "Unshare from me" : "Hætta deilingu frá mér",
@@ -160,7 +157,6 @@ OC.L10N.register(
     "Invalid location selected" : "Ógild staðsetning valin",
     "Attachments folder successfully saved." : "Tókst að vista viðhengjamöppu.",
     "Error on saving attachments folder." : "Villa við að vista viðhengjamöppu.",
-    "Default attachments location" : "Sjálfgefin staðsetning viðhengja",
     "{filename} could not be parsed" : "Ekki var hægt að þátta {filename}",
     "No valid files found, aborting import" : "Engar gildar skrár fundust, hætti innflutningi",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Það tókst að flytja inn %n atburð","Það tókst að flytja inn %n atburði"],
@@ -194,13 +190,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "CalDAV-tengill afritaður á klippispjald.",
     "CalDAV link could not be copied to clipboard." : "Ekki var hægt að afrita CalDAV-tengil á klippispjald.",
     "General" : "Almennt",
-    "Personal availability settings" : "Persónulegar stillingar varðandi hvenær til taks",
-    "Copy primary CalDAV address" : "Afrita aðal-CalDAV-vistfang",
     "Copy iOS/macOS CalDAV address" : "Afrita iOS/macOS CalDAV-vistfang ",
-    "Enable birthday calendar" : "Virkja fæðingardagatal",
-    "Show tasks in calendar" : "Sýna verkefni í dagatali",
-    "Show weekends" : "Sýna helgar",
-    "Show week numbers" : "Sýna vikunúmer",
+    "Appearance" : "Útlit",
     "Editing" : "Breytingar",
     "Default calendar for incoming invitations" : "Sjálfgefið dagatal fyrir boð sem berast",
     "Default reminder" : "Sjálfgefin áminning",
@@ -414,6 +405,7 @@ OC.L10N.register(
     "Update this occurrence" : "Uppfæra þetta tilviki",
     "Public calendar does not exist" : "Opinbert dagatal er ekki til",
     "Maybe the share was deleted or has expired?" : "Hugsanlega hefur sameigninni verið eytt eða hún sé útrunnin?",
+    "None" : "Ekkert",
     "Create" : "Búa til",
     "from {formattedDate}" : "frá {formattedDate}",
     "to {formattedDate}" : "til {formattedDate}",
@@ -544,7 +536,6 @@ OC.L10N.register(
     "When shared show full event" : "Þegar er deilt, birta allan atburð",
     "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
     "When shared hide this event" : "Þegar er deilt, fela þennan atburð",
-    "The visibility of this event in shared calendars." : "Sýnileiki þessa atburðar í sameiginlegum dagatölum",
     "Add a location" : "Bæta við staðsetningu",
     "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Bættu við lýsingu\n\n- Um hvað snýst þessi fundur\n- Atriði á dagskrá\n- Hvaðeina sem þátttakendur þurfa að undirbúa",
     "Status" : "Staða",
@@ -570,11 +561,22 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "Villa við þáttun á PROPFIND-villu",
     "Appointment not found" : "Stefnumót fannst ekki",
     "User not found" : "Notandi fannst ekki",
+    "Hidden" : "Falinn",
+    "can edit" : "getur breytt",
+    "Calendar name …" : "Heiti dagatals …",
+    "Default attachments location" : "Sjálfgefin staðsetning viðhengja",
     "Automatic ({detected})" : "Sjálfvirkt ({detected})",
     "Shortcut overview" : "Yfirlit flýtilykla",
+    "Enable birthday calendar" : "Virkja fæðingardagatal",
+    "Show tasks in calendar" : "Sýna verkefni í dagatali",
     "Enable simplified editor" : "Virkja einfaldaðan ritil",
     "Limit the number of events displayed in the monthly view" : "Takmarka fjölda atburða sem birtast í mánaðaryfirlitinu",
+    "Show weekends" : "Sýna helgar",
+    "Show week numbers" : "Sýna vikunúmer",
     "Time increments" : "Tímaþrep",
-    "Show keyboard shortcuts" : "Birta flýtivísanir á lyklaborði"
+    "Copy primary CalDAV address" : "Afrita aðal-CalDAV-vistfang",
+    "Personal availability settings" : "Persónulegar stillingar varðandi hvenær til taks",
+    "Show keyboard shortcuts" : "Birta flýtivísanir á lyklaborði",
+    "The visibility of this event in shared calendars." : "Sýnileiki þessa atburðar í sameiginlegum dagatölum"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
