@@ -7,7 +7,7 @@ OC.L10N.register(
     "%s has published the calendar »%s«" : "%s dalījās ar kalendāru »%s«",
     "Unexpected error sending email. Please contact your administrator." : "E-pasta ziņojuma nosūtīšanas laikā bija neparedzēta kļūda. Lūgums sazināties ar savu pārvaldītāju.",
     "Successfully sent email to %1$s" : "E-pasta ziņojums sekmīgi nosūtīts uz %1$s",
-    "Hello," : "Sveicināti,",
+    "Hello," : "Sveiciens,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Mēs vēlējāmies ziņot, ka %s padarīja pieejamu kalendāru »%s«.",
     "Open »%s«" : "Atvērt »%s«",
     "Cheers!" : "Priekā!",
@@ -106,7 +106,6 @@ OC.L10N.register(
     "Delete permanently" : "Neatgriezeniski izdzēst",
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Atkritnes vienumi tiek izdzēsti pēc {numDays} dienām","Atkritnes vienumi tiek izdzēsti pēc {numDays} dienas","Atkritnes vienumi tiek izdzēsti pēc {numDays} dienām"],
     "Could not update calendar order." : "Nevarēja atjaunināt kalendāra pasūtījumu.",
-    "Hidden" : "Paslēpts",
     "Internal link" : "Iekšējā saite",
     "A private link that can be used with external clients" : "Privāta saite, kas var tikt izmantota ar ārējiem klientiem.",
     "Copy internal link" : "Ievietot iekšējo saiti starpliktuvē",
@@ -127,12 +126,10 @@ OC.L10N.register(
     "Deleting share link …" : "Dzēš koplietoto saiti ...",
     "An error occurred while unsharing the calendar." : "Atgadījās kļūda kalendāra koplietošanas atcelšanas laikā.",
     "An error occurred, unable to change the permission of the share." : "Atgadījās kļūda, nevar mainīt kopīgojuma atļauju.",
-    "can edit" : "var labot",
     "Unshare with {displayName}" : "Atcelt kopīgošanu ar {displayName}",
     "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
     "No users or groups" : "Nav lietotāji vai grupas",
     "Failed to save calendar name and color" : "Neizdevās saglabāt kalendāra nosaukumu un krāsu.",
-    "Calendar name …" : "Kalendāra nosaukums ...",
     "Never show me as busy (set this calendar to transparent)" : "Nekad nerādīt mani kā aizņemtu (iestatīt šo kalendāru caurspīdīgu)",
     "Share calendar" : "Koplietot kalendāru",
     "Unshare from me" : "Atcelt koplietošanu no manis",
@@ -147,7 +144,6 @@ OC.L10N.register(
     "Invalid location selected" : "Ir izvēlēta nederīga atrašanās vieta ",
     "Attachments folder successfully saved." : "Pielikumu mape saglabāta sekmīgi.",
     "Error on saving attachments folder." : "Kļūda saglabājot pielikumu mapi.",
-    "Default attachments location" : "Pielikumu noklusējuma atrašanās vietas",
     "No valid files found, aborting import" : "Nav atrastas derīgas datnes, ievietošana tiek pārtraukta.",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Sekmīgi ievietoti %n notikumi","Sekmīgi ievietots %n notikums","Sekmīgi ievietoti %n notikumi"],
     "Import partially failed. Imported {accepted} out of {total}." : "Ievietošana daļēji neizdevās. Ievietoti {accepted} no {total}.",
@@ -179,13 +175,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "Kalendāra saite ievietota starpliktuvē.",
     "CalDAV link could not be copied to clipboard." : "Kalendāra saiti neizdevās ievietot starpliktuvē.",
     "General" : "Vispārīgi",
-    "Personal availability settings" : "Personiskās pieejamības iestatījumi",
-    "Copy primary CalDAV address" : "Ievietot starpliktuvē galveno CalDAV adresi",
     "Copy iOS/macOS CalDAV address" : "Kopēt IOS/macOS CalDAV adresi",
-    "Enable birthday calendar" : "Iespējot dzimšanas dienas kalendāru",
-    "Show tasks in calendar" : "Rādīt uzdevumus kalendārā",
-    "Show weekends" : "Rādīt nedēļas nogales",
-    "Show week numbers" : "Rādīt nedēļu numurus",
+    "Appearance" : "Izskats",
     "Editing" : "Labošana",
     "Default reminder" : "Noklusējuma atgādinājums",
     "Keyboard shortcuts" : "Tastatūras saīsnes",
@@ -343,6 +334,7 @@ OC.L10N.register(
     "Maybe the share was deleted or has expired?" : "Varbūt kopīgojums tika izdzēsts, vai arī ir beidzies tā derīgums?",
     "Yes" : "Jā",
     "No" : "Nē",
+    "None" : "Nekas",
     "from {formattedDate}" : "no {formattedDate}",
     "to {formattedDate}" : "līdz {formattedDate}",
     "from {formattedDate} at {formattedTime}" : "no {formattedDate} plkst. {formattedTime}",
@@ -441,7 +433,6 @@ OC.L10N.register(
     "When shared show full event" : "Ja kopīgots, tad rādīt pilnu notikumu",
     "When shared show only busy" : "Ja kopīgots, tad rādīt tikai aizņemtos",
     "When shared hide this event" : "Ja kopīgots, tad paslēpt šo notikumu",
-    "The visibility of this event in shared calendars." : "Šī notikuma redzamība koplietotos kalendāros.",
     "Add a location" : "Pievienot atrašanās vietu",
     "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Pievienot aprakstu\n\n- Par ko ir šī tikšanās\n- Darba kārtības vienumi\n- Jebkas, kam dalībniekiem ir jāsagatavojas",
     "Status" : "Status",
@@ -465,10 +456,21 @@ OC.L10N.register(
     "This is an event reminder." : "Šis ir notikuma atgādinājums.",
     "Appointment not found" : "Tikšanās nav atrasta",
     "User not found" : "Lietotājs nav atrasts",
+    "Hidden" : "Paslēpts",
+    "can edit" : "var labot",
+    "Calendar name …" : "Kalendāra nosaukums ...",
+    "Default attachments location" : "Pielikumu noklusējuma atrašanās vietas",
     "Automatic ({detected})" : "Automātiska ({detected})",
     "Shortcut overview" : "Īsceļu pārskats",
+    "Enable birthday calendar" : "Iespējot dzimšanas dienas kalendāru",
+    "Show tasks in calendar" : "Rādīt uzdevumus kalendārā",
     "Enable simplified editor" : "Iespējot vienkāršoto redaktoru",
     "Limit the number of events displayed in the monthly view" : "Ierobežot notikumu skaitu, kas tiek parādīti mēneša skatā",
-    "Show keyboard shortcuts" : "Rādīt tastatūras saīsnes taustiņus"
+    "Show weekends" : "Rādīt nedēļas nogales",
+    "Show week numbers" : "Rādīt nedēļu numurus",
+    "Copy primary CalDAV address" : "Ievietot starpliktuvē galveno CalDAV adresi",
+    "Personal availability settings" : "Personiskās pieejamības iestatījumi",
+    "Show keyboard shortcuts" : "Rādīt tastatūras saīsnes taustiņus",
+    "The visibility of this event in shared calendars." : "Šī notikuma redzamība koplietotos kalendāros."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
