@@ -41,6 +41,7 @@ OC.L10N.register(
     "Comment:" : "باھا:",
     "You have a new appointment booking \"%s\" from %s" : "سىزدە% s دىن «% s» نى زاكاز قىلىش يېڭى زاكاس تالونى بار",
     "Dear %s, %s (%s) booked an appointment with you." : "ھۆرمەتلىك% s ،% s (% s) سىز بىلەن كۆرۈشۈشنى زاكاز قىلدى.",
+    "Location:" : "ئورنى:",
     "A Calendar app for Nextcloud" : "Nextcloud ئۈچۈن كالېندار دېتالى",
     "Previous day" : "ئالدىنقى كۈن",
     "Previous week" : "ئالدىنقى ھەپتە",
@@ -111,7 +112,6 @@ OC.L10N.register(
     "Could not update calendar order." : "كالېندار تەرتىپىنى يېڭىلىيالمىدى.",
     "Shared calendars" : "ئورتاق كالېندار",
     "Deck" : "پالۋان",
-    "Hidden" : "يۇشۇرۇن",
     "Internal link" : "ئىچكى ئۇلىنىش",
     "A private link that can be used with external clients" : "سىرتقى خېرىدارلار بىلەن ئىشلىتىشكە بولىدىغان شەخسىي ئۇلىنىش",
     "Copy internal link" : "ئىچكى ئۇلىنىشنى كۆچۈرۈڭ",
@@ -134,16 +134,15 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
     "An error occurred while unsharing the calendar." : "كالېندارنى ھەمبەھىرلەۋاتقاندا خاتالىق كۆرۈلدى.",
     "An error occurred, unable to change the permission of the share." : "ئورتاقلىشىشنىڭ رۇخسىتىنى ئۆزگەرتەلمەي خاتالىق كۆرۈلدى.",
-    "can edit" : "تەھرىرلىيەلەيدۇ",
     "Unshare with {displayName}" : "{displayName} بىلەن ئورتاقلاشماسلىق",
     "Share with users or groups" : "ئىشلەتكۈچىلەر ياكى گۇرۇپپىلار بىلەن ئورتاقلىشىڭ",
     "No users or groups" : "ئىشلەتكۈچى ياكى گۇرۇپپا يوق",
     "Failed to save calendar name and color" : "كالېندار ئىسمى ۋە رەڭنى ساقلاش مەغلۇب بولدى",
-    "Calendar name …" : "كالېندار ئىسمى…",
     "Never show me as busy (set this calendar to transparent)" : "مېنى ھەرگىز ئالدىراش دەپ كۆرسەتمەڭ (بۇ كالېندارنى سۈزۈك قىلىپ تەڭشەڭ)",
     "Share calendar" : "كالېندارنى ئورتاقلىشىش",
     "Unshare from me" : "مەندىن تەڭداشسىز",
     "Save" : "ساقلا",
+    "View" : "كۆرۈش",
     "Import calendars" : "كالېندار ئەكىرىڭ",
     "Please select a calendar to import into …" : "ئىمپورت قىلىدىغان كالېندارنى تاللاڭ.",
     "Filename" : "ھۆججەت ئىسمى",
@@ -154,12 +153,12 @@ OC.L10N.register(
     "Invalid location selected" : "ئىناۋەتسىز ئورۇن تاللانغان",
     "Attachments folder successfully saved." : "قوشۇمچە ھۆججەت قىسقۇچ مۇۋەپپەقىيەتلىك ساقلاندى.",
     "Error on saving attachments folder." : "قوشۇمچە ھۆججەت قىسقۇچنى ساقلاشتا خاتالىق.",
-    "Default attachments location" : "كۆڭۈلدىكى قوشۇمچە ئورنى",
+    "Attachments folder" : "قوشۇمچە ھۆججەت قىسقۇچ",
     "{filename} could not be parsed" : "{filename} ئىسمى} تەھلىل قىلىشقا بولمايدۇ",
     "No valid files found, aborting import" : "ئۈنۈملۈك ھۆججەت تېپىلمىدى ، ئىمپورتنى ئەمەلدىن قالدۇردى",
     "Import partially failed. Imported {accepted} out of {total}." : "ئىمپورت قىسمەن مەغلۇپ بولدى. {accepted} دىن ئىمپورت قىلىنغان {total} قىلىندى}.",
     "Automatic" : "ئاپتوماتىك",
-    "Automatic ({detected})" : "ئاپتوماتىك ({detected})",
+    "Automatic ({timezone})" : "ئاپتوماتىك ({timezone})",
     "New setting was not saved successfully." : "يېڭى تەڭشەك مۇۋەپپەقىيەتلىك ساقلانمىدى.",
     "Navigation" : "يول باشلاش",
     "Previous period" : "ئالدىنقى مەزگىل",
@@ -178,7 +177,6 @@ OC.L10N.register(
     "Save edited event" : "تەھرىرلەنگەن پائالىيەتنى ساقلاڭ",
     "Delete edited event" : "تەھرىرلەنگەن ۋەقەنى ئۆچۈرۈڭ",
     "Duplicate event" : "كۆپەيتىلگەن ھادىسە",
-    "Shortcut overview" : "تېزلەتمە ئومۇمىي كۆرۈنۈش",
     "or" : "ياكى",
     "Calendar settings" : "كالېندار تەڭشىكى",
     "At event start" : "پائالىيەت باشلانغاندا",
@@ -186,19 +184,13 @@ OC.L10N.register(
     "Failed to save default calendar" : "سۈكۈتتىكى كالېندارنى ساقلىيالمىدى",
     "CalDAV link copied to clipboard." : "CalDAV ئۇلىنىشى چاپلاش تاختىسىغا كۆچۈرۈلدى.",
     "CalDAV link could not be copied to clipboard." : "CalDAV ئۇلانمىسىنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ.",
-    "Enable birthday calendar" : "تۇغۇلغان كۈن كالىندارىنى قوزغىتىڭ",
-    "Show tasks in calendar" : "كالېنداردىكى ۋەزىپىلەرنى كۆرسەت",
-    "Enable simplified editor" : "ئاددىيلاشتۇرۇلغان تەھرىرلىگۈچنى قوزغىتىڭ",
-    "Limit the number of events displayed in the monthly view" : "ئايلىق كۆرۈنۈشتە كۆرسىتىلگەن پائالىيەت سانىنى چەكلەڭ",
-    "Show weekends" : "ھەپتە ئاخىرىنى كۆرسەت",
-    "Show week numbers" : "ھەپتە نومۇرىنى كۆرسەت",
-    "Time increments" : "ۋاقىت كۆپەيدى",
+    "General" : "General",
+    "Copy iOS/macOS CalDAV address" : "IOS / macOS CalDAV ئادرېسىنى كۆچۈرۈڭ",
+    "Appearance" : "كۆرۈنۈش",
+    "Editing" : "تەھرىرلەش",
     "Default calendar for incoming invitations" : "كەلگەن تەكلىپلەرنىڭ سۈكۈتتىكى كالېندارى",
     "Default reminder" : "كۆڭۈلدىكى ئەسكەرتىش",
-    "Copy primary CalDAV address" : "دەسلەپكى CalDAV ئادرېسىنى كۆچۈرۈڭ",
-    "Copy iOS/macOS CalDAV address" : "IOS / macOS CalDAV ئادرېسىنى كۆچۈرۈڭ",
-    "Personal availability settings" : "شەخسىي ئىشلىتىش تەڭشىكى",
-    "Show keyboard shortcuts" : "كۇنۇپكا تاختىسىنىڭ تېزلەتمىسىنى كۆرسەت",
+    "Keyboard shortcuts" : "كۇنۇپكا تاختىسى تېزلەتمىسى",
     "Appointment schedule successfully created" : "تەيىنلەش جەدۋىلى مۇۋەپپەقىيەتلىك قۇرۇلدى",
     "Appointment schedule successfully updated" : "تەيىنلەش جەدۋىلى مۇۋەپپەقىيەتلىك يېڭىلاندى",
     "0 minutes" : "0 مىنۇت",
@@ -245,11 +237,9 @@ OC.L10N.register(
     "Please share anything that will help prepare for our meeting" : "ئۇچرىشىشىمىزغا تەييارلىق قىلىشقا ياردىمى بولىدىغان نەرسىلەرنى ئورتاقلىشىڭ",
     "Could not book the appointment. Please try again later or contact the organizer." : "ئۇچرىشىشنى زاكاز قىلالمىدى. كېيىن قايتا سىناڭ ياكى تەشكىللىگۈچى بىلەن ئالاقىلىشىڭ.",
     "Back" : "قايتىش",
-    "Create a new conversation" : "يېڭى سۆھبەت قۇر",
     "Select conversation" : "سۆھبەتنى تاللاڭ",
     "on" : "on",
     "at" : "at",
-    "Reminder" : "ئەسكەرتىش",
     "before at" : "before at",
     "Notification" : "ئۇقتۇرۇش",
     "Email" : "تورخەت",
@@ -260,7 +250,6 @@ OC.L10N.register(
     "Edit time" : "ۋاقىتنى تەھرىرلەش",
     "Save time" : "ۋاقىت تېجەڭ",
     "Remove reminder" : "ئەسكەرتىشنى ئۆچۈرۈڭ",
-    "+ Add reminder" : "+ ئەسكەرتىش قوشۇڭ",
     "Add reminder" : "ئەسكەرتىش قوشۇڭ",
     "seconds" : "سېكۇنت",
     "minutes" : "مىنۇت",
@@ -290,26 +279,25 @@ OC.L10N.register(
     "Awaiting response" : "جاۋاب كۈتۈش",
     "Checking availability" : "بار-يوقلۇقىنى تەكشۈرۈش",
     "Has not responded to {organizerName}'s invitation yet" : "{organizerName} نىڭ تەكلىپىگە تېخى جاۋاب بەرمىدى",
-    "Select automatic slot" : "ئاپتوماتىك ئورۇننى تاللاڭ",
     "chairperson" : "رەئىس",
     "required participant" : "تەلەپچان قاتناشقۇچى",
     "non-participant" : "قاتناشمىغان",
     "optional participant" : "ئىختىيارى قاتناشقۇچى",
     "{organizer} (organizer)" : "{organizer} (تەشكىللىگۈچى)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "ھەقسىز",
-    "Busy (tentative)" : "ئالدىراش (ۋاقىتلىق)",
-    "Busy" : "ئالدىراش",
-    "Out of office" : "ئىشخانىدىن چىقتى",
-    "Unknown" : "نامەلۇم",
     "Availability of attendees, resources and rooms" : "قاتناشقۇچىلار ، بايلىق ۋە ياتاقلار",
-    "with" : "with",
-    "Available times:" : "ئىشلەتكىلى بولىدىغان ۋاقىت:",
     "Suggestion accepted" : "تەكلىپ قوبۇل قىلىندى",
+    "Legend" : "رىۋايەت",
+    "Out of office" : "ئىشخانىدىن چىقتى",
+    "Attendees:" : "قاتناشقۇچىلار:",
     "Done" : "تامام",
     "Search room" : "ئىزدەش ئۆيى",
     "Room name" : "ياتاق ئىسمى",
     "Check room availability" : "ياتاقنىڭ بار-يوقلۇقىنى تەكشۈرۈڭ",
+    "Free" : "ھەقسىز",
+    "Busy (tentative)" : "ئالدىراش (ۋاقىتلىق)",
+    "Busy" : "ئالدىراش",
+    "Unknown" : "نامەلۇم",
     "Find a time" : "ۋاقىت تېپىڭ",
     "The invitation has been accepted successfully." : "تەكلىپ مۇۋەپپەقىيەتلىك قوبۇل قىلىندى.",
     "Failed to accept the invitation." : "تەكلىپنى قوبۇل قىلالمىدى.",
@@ -344,7 +332,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "تەكرارلىنىشنىڭ بىر قىسمى بولغان ۋەقەلەرنىڭ پۈتۈن كۈنلۈك تەڭشىكىنى ئۆزگەرتەلمەيدۇ.",
     "From" : "From",
     "To" : "To",
-    "All day" : "پۈتۈن كۈن",
     "Repeat" : "قايتىلا",
     "never" : "ھەرگىز",
     "on date" : "on date",
@@ -362,7 +349,7 @@ OC.L10N.register(
     "Does not repeat" : "تەكرارلانمايدۇ",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "بۇ پائالىيەتنىڭ قايتا-قايتا ئېنىقلىنىشى Nextcloud تەرىپىدىن تولۇق قوللىمايدۇ. ئەگەر قايتا-قايتا تاللاشلارنى تەھرىرلىسىڭىز ، بەزى تەكرارلىنىشلار يوقاپ كېتىشى مۇمكىن.",
     "No rooms or resources yet" : "ھازىرچە ياتاق ۋە بايلىق يوق",
-    "Suggestions" : "تەكلىپ",
+    "Resources" : "بايلىق",
     "Add resource" : "بايلىق قوشۇڭ",
     "Has a projector" : "بىر پروجېكتور بار",
     "Has a whiteboard" : "ئاق دوسكىسى بار",
@@ -382,6 +369,12 @@ OC.L10N.register(
     "Update this occurrence" : "بۇ ھادىسىنى يېڭىلاڭ",
     "Public calendar does not exist" : "ئاممىۋى كالېندار مەۋجۇت ئەمەس",
     "Maybe the share was deleted or has expired?" : "بەلكىم ھەمبەھىر ئۆچۈرۈلگەن ياكى ۋاقتى توشقان بولۇشى مۇمكىن؟",
+    "Remove participant" : "قاتناشقۇچىنى ئېلىۋېتىڭ",
+    "Yes" : "ھەئە",
+    "No" : "ياق",
+    "Maybe" : "مۇمكىن",
+    "None" : "يوق",
+    "Create" : "قۇر",
     "from {formattedDate}" : "from {formattedDate}",
     "to {formattedDate}" : "to {formattedDate}",
     "on {formattedDate}" : "on {formattedDate}",
@@ -405,7 +398,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "ئىناۋەتلىك ئاممىۋى كالېندار سەپلەنمىدى",
     "Speak to the server administrator to resolve this issue." : "بۇ مەسىلىنى ھەل قىلىش ئۈچۈن مۇلازىمېتىر باشقۇرغۇچىغا سۆزلەڭ.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "ئاممىۋى دەم ئېلىش كالېندارىنى Thunderbird تەمىنلەيدۇ. كالېندار سانلىق مەلۇماتلىرى {website} بېكىتى} دىن چۈشۈرۈلىدۇ",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "بۇ ئاممىۋى كالېندارلارنى كەسمە باشقۇرغۇچى تەۋسىيە قىلىدۇ. كالېندار سانلىق مەلۇماتلىرى مۇناسىۋەتلىك تور بەتتىن چۈشۈرۈلىدۇ.",
     "By {authors}" : "{authors}",
     "Subscribed" : "مۇشتەرى بولدى",
     "Subscribe" : "مۇشتەرى بولۇش",
@@ -431,13 +423,17 @@ OC.L10N.register(
     "Duplicate" : "كۆپەيتىلگەن",
     "Delete this occurrence" : "بۇ ھادىسىنى ئۆچۈرۈڭ",
     "Delete this and all future" : "بۇنى ۋە كەلگۈسىنى ئۆچۈرۈڭ",
-    "Details" : "تەپسىلاتى",
+    "All day" : "پۈتۈن كۈن",
     "Managing shared access" : "ئورتاق زىيارەتنى باشقۇرۇش",
     "Deny access" : "زىيارەتنى رەت قىلىش",
     "Invite" : "تەكلىپ قىلىڭ",
-    "Resources" : "بايلىق",
     "Untitled event" : "نامسىز ھادىسە",
     "Close" : "ياپ",
+    "Selected" : "تاللانغان",
+    "Title" : "ماۋزۇ",
+    "30 min" : "30 مىنۇت",
+    "Participants" : "قاتناشقۇچىلار",
+    "Submit" : "يوللاڭ",
     "Subscribe to {name}" : "{name} غا مۇشتەرى بولۇڭ",
     "Export {name}" : "چىقىرىش {name}",
     "Anniversary" : "يىللىق خاتىرە كۈنى",
@@ -496,7 +492,6 @@ OC.L10N.register(
     "When shared show full event" : "ھەمبەھىرلەنگەندە تولۇق پائالىيەتنى كۆرسىتىدۇ",
     "When shared show only busy" : "ئورتاقلاشقاندا پەقەت ئالدىراش",
     "When shared hide this event" : "ئورتاقلاشقاندا بۇ پائالىيەتنى يوشۇرۇڭ",
-    "The visibility of this event in shared calendars." : "ئورتاق كالېنداردا بۇ پائالىيەتنىڭ كۆرۈنۈشچانلىقى.",
     "Add a location" : "ئورۇن قوشۇڭ",
     "Status" : "ھالەت",
     "Confirmed" : "جەزملەشتۈرۈلدى",
@@ -519,6 +514,23 @@ OC.L10N.register(
     "This is an event reminder." : "بۇ بىر ۋەقە ئەسكەرتىش.",
     "Error while parsing a PROPFIND error" : "PROPFIND خاتالىقىنى تەھلىل قىلغاندا خاتالىق",
     "Appointment not found" : "تەيىنلەنمىدى",
-    "User not found" : "ئىشلەتكۈچى تېپىلمىدى"
+    "User not found" : "ئىشلەتكۈچى تېپىلمىدى",
+    "Hidden" : "يۇشۇرۇن",
+    "can edit" : "تەھرىرلىيەلەيدۇ",
+    "Calendar name …" : "كالېندار ئىسمى…",
+    "Default attachments location" : "كۆڭۈلدىكى قوشۇمچە ئورنى",
+    "Automatic ({detected})" : "ئاپتوماتىك ({detected})",
+    "Shortcut overview" : "تېزلەتمە ئومۇمىي كۆرۈنۈش",
+    "Enable birthday calendar" : "تۇغۇلغان كۈن كالىندارىنى قوزغىتىڭ",
+    "Show tasks in calendar" : "كالېنداردىكى ۋەزىپىلەرنى كۆرسەت",
+    "Enable simplified editor" : "ئاددىيلاشتۇرۇلغان تەھرىرلىگۈچنى قوزغىتىڭ",
+    "Limit the number of events displayed in the monthly view" : "ئايلىق كۆرۈنۈشتە كۆرسىتىلگەن پائالىيەت سانىنى چەكلەڭ",
+    "Show weekends" : "ھەپتە ئاخىرىنى كۆرسەت",
+    "Show week numbers" : "ھەپتە نومۇرىنى كۆرسەت",
+    "Time increments" : "ۋاقىت كۆپەيدى",
+    "Copy primary CalDAV address" : "دەسلەپكى CalDAV ئادرېسىنى كۆچۈرۈڭ",
+    "Personal availability settings" : "شەخسىي ئىشلىتىش تەڭشىكى",
+    "Show keyboard shortcuts" : "كۇنۇپكا تاختىسىنىڭ تېزلەتمىسىنى كۆرسەت",
+    "The visibility of this event in shared calendars." : "ئورتاق كالېنداردا بۇ پائالىيەتنىڭ كۆرۈنۈشچانلىقى."
 },
 "nplurals=2; plural=(n != 1);");
